Visibility
====================

This module contains functions for calculating visibility in Counter-Strike 2 demos.

awpy.visibility
------------------------------

.. automodule:: awpy.visibility
   :members:
   :undoc-members:
   :show-inheritance:
   :exclude-members: Edge, Triangle